# eric7.WebBrowser.Tools.PrintToPdfDialog

Module implementing a dialog to enter the data for printing a web page to PDF.

### Global Attributes

None

### Classes

PrintToPdfDialog | Class implementing a dialog to enter the data for printing a web page to PDF.

### Functions

None

## PrintToPdfDialog

Class implementing a dialog to enter the data for printing a web page to PDF.

### Derived from

QDialog, Ui_PrintToPdfDialog

### Class Attributes

None

### Class Methods

None

### Methods

PrintToPdfDialog | Constructor
__updatePageLayoutLabel | Private method to update the page layout label.
getData | Public method to get the dialog data.
on_pageLayoutButton_clicked | Private slot to define the page layout.

### Static Methods

None

#### PrintToPdfDialog (Constructor)

PrintToPdfDialog(printer, parent=None)

Constructor

printer (QPrinter)
  reference to an initialized QPrinter object
parent (QWidget)
  reference to the parent widget

#### PrintToPdfDialog.__updatePageLayoutLabel

__updatePageLayoutLabel()

Private method to update the page layout label.

#### PrintToPdfDialog.getData

getData()

Public method to get the dialog data.

Return:
  tuple containing the file path and the page layout

Return Type:
  tuple of str and QPageLayout

#### PrintToPdfDialog.on_pageLayoutButton_clicked

on_pageLayoutButton_clicked()

Private slot to define the page layout.

Up